/* Window Picker */

$window_picker_spacing: $space-size; // 6px
$window_picker_padding: $space-size * 2; // 12px
$window_close_button_size: 30px;
$window_close_button_padding: 3px;

// Window picker
.window-picker {
  // Space between window thumbnails
  spacing: $window_picker_spacing;
}

// Window titles
.window-caption {
  color: on(dark);
  background-color: $tooltip;
  border-radius: if($corner-style == 'circular', $circular-radius, $material-radius);
  padding: $space-size $space-size * 2;
  box-shadow: none;
  border: none;
}

// Close button
.window-close {
  background-color: $system;
  color: on(dark);
  border-radius: $circular-radius;
  padding: $window_close_button_padding;
  height: $window_close_button_size;
  width: $window_close_button_size;
  box-shadow: -1px 1px 5px 0px rgba(0,0,0,0.5);
  transition-duration: 300ms;

  & StIcon { icon-size: 24px; }

  &:hover {
    background-color: lighten($system, 15%);
  }

  &:active {
    color: transparentize(on(dark), 0.2);
    background-color: darken($system, 5%);
  }
}

.workspace-background {
  // keep in sync with BACKGROUND_CORNER_RADIUS_PIXELS in workspace.js
  border-radius: 30px;
  background-color: $system;
  box-shadow: 0 4px 16px 4px rgba(black, 0.15);
}
