/* Check Boxes */

.check-box {
  StBoxLayout { spacing: .8em; }

  StBin {
    width: 24px;
    height: 24px;
    padding: ($medium-size - 24px) / 2;
    border-radius: 100px;
    background-image: url("assets/checkbox-off.svg");
  }

  &:focus StBin {
    background-image: url("assets/checkbox-off.svg");
  }

  &:hover StBin {
    background-color: $secondary-fill;
  }

  &:active StBin {
    background-color: $track;
  }

  &:checked StBin {
    background-image: url("assets/checkbox.svg");
  }

  &:focus:checked StBin {
    background-image: url("assets/checkbox.svg");
  }

  &:hover:checked StBin {
    background-color: rgba($primary, 0.3 / 2);
  }

  &:active:checked StBin {
    background-color: rgba($primary, 0.3);
  }

  StIcon {
    icon-size: 0;
    padding: 0;
    color: transparent;
    border: none;
  }

  &:hover StIcon,
  &:active StIcon {
    border: none;
  }

  &:checked StIcon,
  &:checked:hover StIcon,
  &:checked:active StIcon {
    background-color: transparent;
    color: transparent;
  }
}
