// based css:
// https://github.com/solus-project/budgie-desktop/tree/master/src/theme

/******************
 * Budgie Desktop *
 ******************/
// Container for both the "panel" area and the shadow. Wise to keep
// this transparent..
.budgie-container { background-color: transparent; }

// Budgie popover
.budgie-popover {
  border: none;
  border-radius: $corner-radius;
  box-shadow: $shadow-z3;
  background-color: $base;
  border-color: $base;

  > .container {
    padding: $space-size;

    .container {
      padding: 0;
    }
  }

  separator { margin: $space-size / 2 0; }

  border { border: none; }

  list { background-color: transparent; }

  entry, button, spinbutton, button.combo {
    border-radius: $menuitem-radius;
  }

  .linked > entry,
  .linked > button {
    &:first-child {
      border-top-left-radius: $menuitem-radius;
      border-bottom-left-radius: $menuitem-radius;
    }

    &:last-child {
      border-top-right-radius: $menuitem-radius;
      border-bottom-right-radius: $menuitem-radius;
    }
  }

  button.flat:not(.image-button) {
    min-height: $menuitem-size;
    padding: 0 8px;
    color: $text;
    font-weight: normal;
    border-radius: $menuitem-radius;

    &:disabled { color: $text-disabled; }
  }

  row {
    padding: 0;

    &:hover { box-shadow: none; }

    button {
      @extend %button-flat-simple;
      border-radius: $menuitem-radius;
    }
  }

  calendar:not(.header) { border-radius: $menuitem-radius; }

  scrolledwindow.sidebar.categories { // AppMenu
    background-color: $fill;

    button.category-button {
      border-radius: 0;
    }
  }

  treeview.view.sidebar { //AppMenu (Elementary) old version
    // min-height: 36px;
    background: none;
    border-right: none;
    color: $text;
    padding: $space-size / 2;

    // label { padding: $space-size / 2 $space-size * 1.5; }

    &:hover { background-color: $overlay-hover; }

    &:selected { background-color: $overlay-active; }
  }

  // AppMenu (Elementary)
  scrolledwindow.sidebar:not(.categories) {
    border-right: none;
    background: none;

    list {
      background-color: $fill;
      border-radius: $corner-radius / 2;
      padding: $space-size / 2;

      > row.activatable {
        @extend %row_activatable;
        border-radius: $corner-radius / 4;
        padding: $space-size ($space-size + 2px);
      }
    }
  }

  scrolledwindow.sidebar + separator {
    background-color: transparent;
    min-width: 0;
    min-height: 0;
  }

  scrolledwindow.sidebar + separator + scrolledwindow {
    margin-left: $space-size / 2;
  
    list {
      > row.activatable {
        @extend %row_activatable;
        border-radius: $corner-radius / 2;
      }
    }
  }

  &.budgie-menu {
    .container { padding: 0; }

    .sidebar,
    scrollbar,
    entry.search { background-color: transparent; }

    entry.search {
      border-bottom: 1px solid $divider;
      border-image: none;
      border-radius: 0;
      box-shadow: none;
      font-size: 120%;
    }

    row.activatable > button.flat {
      @extend %row_activatable;
      min-height: 32px;
      padding: 0 8px;
      border-radius: 0;

      &:checked { @extend %selected_items; }

      &:checked:disabled { background-color: transparent; } // remove pointless indicator
    }

    list.left-overlay-menu {
      box-shadow: $shadow-z4, inset 0 1px highlight($base);
      background-color: $base;
      padding: $space-size;
      margin: $space-size;
      border-radius: $menu-radius;

      > row.activatable {
        border-radius: $menuitem-radius;

        &:not(:last-child) {
          margin-bottom: $space-size / 2;
        }

        button.menuitem {
          border-radius: $menuitem-radius;
        }
      }
    }

    .budgie-menu-footer {
      border-top: 1px solid $border;
      padding: $space-size;

      button.flat {
        min-height: 16px;
        min-width: 16px;
        padding: $space-size;
        border-radius: $menuitem-radius;

        &.image-button {
          border-radius: $circular-radius;

          &:not(.last-child) {
            margin-right: $space-size;
          }
        }
      }
    }
  }

  &.user-menu {
    // .container { padding: $space-size; }

    list,
    row { // reset styling
      border: none;
      background: none;
      box-shadow: none;
    }

    // top-row (user-name and avatar)
    > frame.container > box.vertical row.activatable:first-child {
      margin-bottom: $space-size / 2;
      outline-width: 0;
      border-radius: $corner-radius;

      button.indicator-item {
        transition: none;
        animation: none;
      }
    }
  }

  &.sound-popover {
    .container { padding: 0; }
    separator { margin: $space-size / 2 0; }
  }

  &.night-light-indicator {
    .container { padding: $space-size / 2; }
    .view-header { margin: 0 $space-size; }
  }

  &.places-menu {
    .container { padding: $space-size / 2; }

    .name-button {
      image {
        &:dir(ltr) { margin-right: 8px - 5px; }
        &:dir(rtl) { margin-left: 8px - 5px; }
      }
    }

    .unmount-button {
      margin: ($menuitem-size - $small-size) / 2;
      padding: 0;
    }

    .places-list:not(.always-expand) {
      margin-top: $space-size / 2;
      padding-top: $space-size / 2;
      border-top: 1px solid $divider;
    }

    // use such sizes for consistency with other hard-coded dim-label sizes
    .alternative-label {
      padding: $space-size / 2;
      font-size: 15px;
    }
  }

  &.workspace-popover {
    // .container { padding: $space-size; }

    flowboxchild { padding: 0; }
  }
}

// FIXME: workspace has unnecessary/unknown margin
.workspace-switcher {
  .workspace-layout {
    border: 0 solid on($panel, divider);

    .top &,
    .bottom & {
      &:dir(ltr) { border-left-width: 1px; }

      &:dir(rtl) { border-right-width: 1px; }
    }

    .left &,
    .right & { border-top-width: 1px; }
  }

  .workspace-item,
  .workspace-add-button {
    border: 0 solid on($panel, divider);

    .top &,
    .bottom & {
      &:dir(ltr) { border-right-width: 1px; }

      &:dir(rtl) { border-left-width: 1px; }
    }

    .left &,
    .right & { border-bottom-width: 1px; }
  }

  .workspace-item {
    transition: $transition;

    &.current-workspace { background-color: $overlay-checked; }
  }

  .workspace-add-button {
    &:hover { box-shadow: none; }

    &:active { background-image: none; }

    &:active image { margin: 1px 0 -1px; }
  }

  .workspace-icon-button {
    .budgie-panel & { // to overwrite the .budgie-panel button style below
      min-height: 24px;
      min-width: 24px;
      padding: 0;
      border-radius: $corner-radius;
    }
  }
}

%panel_circular_button {
  padding: 0;
  margin: ($space-size / 2) 0;
  min-width: 16px;
  min-height: 16px;
  color: on($panel, secondary);

  &, &:hover, &:active, &:checked {
    background: none;
    box-shadow: none;
  }

  image {
    padding: 0;
    margin: 0;
    border-radius: $circular-radius;
    background-image: image(on($panel, divider));
  }

  &:hover {
    color: on($panel);

    image {
      background-image: image(rgba(white, 0.20));
    }
  }

  &:active, &:checked {
    color: on($panel);

    image {
      background-image: image(rgba(white, 0.28));
    }
  }
}

// Panel
.budgie-panel {
  transition: background-color $duration $ease-out;
  background-color: $panel-solid;
  color: on($panel, secondary);
  font-weight: 500;

  &.transparent { background-color: $panel; }

  .bottom & {
    &.dock-mode {
      border-radius: $window-radius $window-radius 0 0;

      .icon-tasklist {
        button.launcher {
          &:checked, &:active { color: on($panel); }
        }

        > box > revealer {
          &:first-child > button.launcher { border-top-left-radius: $window-radius; }
          &:last-child > button.launcher { border-top-right-radius: $window-radius; }
        }
      }
    }
  }

  .left & {
    &.dock-mode {
      border-radius: 0 $window-radius $window-radius 0;

      .icon-tasklist {
        > box > revealer {
          &:first-child > button.launcher { border-top-right-radius: $window-radius; }
          &:last-child > button.launcher { border-bottom-right-radius: $window-radius; }
        }
      }
    }
  }

  .right & {
    &.dock-mode {
      border-radius: $window-radius 0 0 $window-radius;

      .icon-tasklist {
        > box > revealer {
          &:first-child > button.launcher { border-top-left-radius: $window-radius; }
          &:last-child > button.launcher { border-bottom-left-radius: $window-radius; }
        }
      }
    }
  }

  button {
    @extend %button-flat-simple;
    color: on($panel, secondary);
    min-height: 24px;
    min-width: 24px;
    padding: 0;
    border-radius: 0;

    &:hover { color: on($panel); }

    &:active { color: on($panel, secondary); }

    // Menu Button
    // &.budgie-menu-launcher {
    //   @extend %panel_circular_button;
    //   color: on($panel, secondary);

    //   &:focus { // Fixed issues when global menubar item is hovering
    //     background: none;
    //     box-shadow: none;
    //     border: none;
    //     color: on($panel, secondary);
    //   }
    // }

    // Raven Trigger
    &.raven-trigger {
      color: on($panel, secondary);
    }
  }

  &.horizontal button { padding: 0 4px; }

  &.vertical button { padding: 4px 0; }

  separator { background-color: on($panel, track); }

  // used to indicate unread notifications
  .alert { color: $suggested; }

  // End Section needs to be fancy
  // .end-region { }

  // budgie-pixel-saver-applet
  .titlebar:not(headerbar) {
    min-height: 0;
    padding: 0;
    box-shadow: none;
    background-color: transparent;
    color: on($panel);

    button:not(.suggested-action):not(.destructive-action) {
      color: on($panel, secondary);

      &:hover,
      &:active { color: on($panel); }
    }
  }

  // Budgie styled Gtk Menus
  menubar,
  .menubar {
    color: on($panel, secondary);

    > menuitem {
      color: on($panel, secondary);

      &:hover, &:active {
        color: on($panel);
      }
    }

    separator {
      background-color: $border;
    }
  }

  // Tasklist
  #tasklist-button {
    padding: 0 $space-size;

    @extend %underscores;
  }

  &.vertical #tasklist-button { min-height: 32px; }

  // Icon Tasklist
  button.flat.launcher {
    padding: 0;

    // for indicator colors
    &:not(:checked) {
      color: on($panel, disabled);

      &:hover, &:active { color: on($panel, secondary); }

      &:disabled { color: on($panel, secondary-disabled); }
    }
  }

  .unpinned button.flat.launcher,
  .pinned button.flat.launcher.running {
    @each $pos, $b_pos, $b_wid in (top,    center calc(1px),        2 0 0 0 / 2px 0 0 0),
                                  (bottom, center calc(100% - 1px), 0 0 2 0 / 0 0 2px 0),
                                  (left,   calc(1px) center,        0 0 0 2 / 0 0 0 2px),
                                  (right,  calc(100% - 1px) center, 0 2 0 0 / 0 2px 0 0) {
      .#{$pos} & {
        &:checked {
          border-image: radial-gradient(circle closest-corner at #{$b_pos},
                                        currentColor 100%,
                                        transparent 0%)
                                        #{$b_wid};
        }
      }
    }
  }

  .lock-keys {
    image:disabled { color: on($panel, secondary-disabled); }
  }

  // Add padding for panel indicators icons
  > box > widget > widget {
    > image, // normal
    > stack > image, // Screenshot
    > box > image { // Places
      margin-left: $space-size;
      margin-right: $space-size;
    }

    > box > image + label { // Reset for mailneg
      margin-left: -$space-size + 2px;
    }

    > box { // keyboard Layout
      > widget > image { margin-left: $space-size; }
      > stack > widget > label { margin-right: $space-size; }
    }

    > box > widget > widget > image { // Status
      margin-left: $space-size / 2;
      margin-right: $space-size / 2;
    }
  }

  // Time label
  .budgie-clock-applet,
  .budgie-calendar-applet {
    > widget > box {
      padding-left: $space-size / 2;
      padding-right: $space-size / 2;
    }
  }
}

%underscores {
  @each $pos, $b_pos, $b_wid in (top,    center calc(1px),        2 0 0 0 / 2px 0 0 0),
                                (bottom, center calc(100% - 1px), 0 0 2 0 / 0 0 2px 0),
                                (left,   calc(1px) center,        0 0 0 2 / 0 0 0 2px),
                                (right,  calc(100% - 1px) center, 0 2 0 0 / 0 2px 0 0) {
    .#{$pos} & {
      & {
        border-image: radial-gradient(circle closest-corner at #{$b_pos},
                                      currentColor 0%,
                                      transparent 0%)
                                      0 0 0 0 / 0 0 0 0;
      }

      &:checked {
        border-image: radial-gradient(circle closest-corner at #{$b_pos},
                                      currentColor 100%,
                                      transparent 0%)
                                      #{$b_wid};
      }
    }
  }
}

frame.raven-frame > border {
  border-style: none;
}

$pos_list: ((top, bottom), (bottom, top), (left, right), (right, left));

@each $pos, $b_pos in $pos_list {
  // Raven borders
  .#{$pos} frame.raven-frame > border {
    margin-#{$b_pos}: 32px;
  }
}

// Raven
.raven {
  background-color: $surface;
  box-shadow: $shadow-z16;

  @if $panel_style == "float" {
    margin: 8px 6px 6px;
    border-radius: $corner-radius;

    scrollbar {
      background-color: transparent;
    }
  }

  // > box { margin-bottom: -10px; } // remove extra space between box and .raven-header.bottom

  stackswitcher.linked {
    margin: 6px 16px;

    > button {
      @extend %button-flat;

      &:focus { box-shadow: none; }
    }
  }

  .raven-header {
    min-height: $medium-size;
    padding: 3px;

    &.top {
      padding: 0;
      border-bottom: 1px solid $divider;

      stackswitcher button {
        // margin: -4px 0 -5px; // remove unwanted vertical margins
        padding: 0 16px;
        min-height: $medium-size;
      }
    }

    &.bottom { border-top: 1px solid $divider; }
  }

  stack {
    .raven-header { margin-top: -6px; } // remove extra space in Notifications stack

    scrolledwindow .raven-header { margin-top: -8px; } // remove extra spaces in Applets stack
  }

  .expander-button { @extend %circular-button; }

  .raven-background {
    border-style: solid none;
    border-width: 1px;
    border-color: $divider;
    background-color: $base;

    // &.middle { border-bottom-style: none; } // applet background between two headers

    > overlay > widget > image { color: $divider; }
  }

  scrolledwindow.raven-background { border-bottom-style: none; }

  .powerstrip button {
    margin: 2px 0 1px;
    padding: ($large-size - 24px) / 2;
  }

  .option-subtitle { font-size: smaller; }

  .audio-widget {
    scale.marks-after {
      padding-top: 0;
      padding-bottom: 0;
    }

    button.flat.expander-button {
      margin-top: 4px;
      margin-bottom: 4px;
    }

    list { background: none; }

    list.devices-list.sound-devices {
      > row.activatable {
        &:selected, &:checked {
          background-color: rgba($text, 0.06);
          color: $text;

          label { color: $text; }
        }

        label { padding-left: 12px; }
      }
    }
  }

  levelbar {
    &, trough, block {
      border-radius: $circular-radius;
    }
  }
}

// Calendar
calendar.raven-calendar {
  // padding: 3px;
  border-style: none;
  background-color: transparent;

  &:selected {
    @extend %selected_items;

    border-radius: $corner-radius;
  }
}

// MPRIS Applet
.raven-mpris {
  background-color: $scrim;
  color: on($scrim, secondary);

  label { min-height: 24px; }

  button.image-button {
    padding: ($large-size - 24px) / 2;

    @extend %button-on-dark;
  }
}

image.raven-mpris {
  background-color: $divider;
  color: $text-secondary;
  border-radius: $corner-radius;
}

// notification list
.raven-notifications-view {
  > .raven-background > viewport.frame {
    padding: 0; // reset padding for full-width list node

    > list > row.activatable {
      margin-left: -$space-size;
      margin-right: -$space-size / 2;

      .raven-notifications-group-header { padding: 0 $space-size * 2; }

      // sub-list rows grouping
      list {
        padding: $space-size;
        background: none;

        > row.activatable {
          border: none;
          padding: $space-size $space-size $space-size $space-size * 2;
          margin: $space-size / 2;
          border-radius: $corner-radius;
          background-color: $fill;

          &:hover, &:selected {
            background-color: $divider;
          }
        }
      }

      &:selected, &:selected:hover, &:hover, &:active, &:focus {
        background: none;
        box-shadow: none;
      }
    }
  }
}

.raven-notifications-group {
  .raven-notifications-group-header {
    padding-left: $space-size;
  }

  list > row {
    border-radius: $corner-radius;
    padding: $space-size;

    .notification-clone {
      padding-left: $space-size;
    }

    button.flat {
      @extend %circular-button;
    }
  }
}

.drop-shadow {
  margin: 5px 9px;
  padding: $space-size;
  border-radius: $window-radius;
  box-shadow: $shadow-z4, inset 0 1px highlight($surface);
  background-color: $surface;

  button { @extend %button-flat-simple; }
}

// Notifications
.budgie-notification-window {
  background-color: transparent;

  .linked > button {
    &, &:first-child, &:last-child {
      @extend %circular-button;
    }
  }
}

.budgie-notification {
  padding: $space-size * 2;

  .notification-title { font-size: 120%; }

  .notification-body { color: $text-secondary; }
}

// Alt+tab switcher in Budgie
.budgie-switcher-window {
  background-color: transparent;
}

// Internal part of the Switcher
.budgie-switcher {
  padding: $space-size * 2;
}

.budgie-osd-window { // On Screen Display in Budgie
  background-color: transparent;
  color: on($osd, secondary);

  .drop-shadow {
    box-shadow: $shadow-z4, inset 0 1px highlight($osd);
    background-color: $osd;

    button { @extend %button-on-dark; }
  }
}

.budgie-osd-window {
  image { color: on($osd, secondary); }

  progressbar trough {
    background-color: on($osd, track-disabled);
  }
}

.budgie-power-dialog {
  box-shadow: inset 0 1px highlight($surface);
  background-color: $surface;

  &.background, decoration {
    border-radius: $window-radius + $space-size;
  }

  .titlebar {
    background: none;
    box-shadow: none;
  }

  .drop-shadow {
    border-radius: $window-radius + $space-size;
  }
}

// Internal part of the OSD
// .budgie-osd {
//   .budgie-osd-text { font-size: 120%; }
// }

%budgie_dialog {
  box-shadow: inset 0 1px highlight($surface);
  background-color: $surface;

  > box > grid {
    padding: $space-size * 4;
  }
}

// Dialogs
.budgie-session-dialog,
.budgie-polkit-dialog,
.budgie-run-dialog {
  @extend %budgie_dialog;

  &.background.csd, decoration { border-radius: $window-radius; }

  label:not(:last-child),
  .dialog-title {
    font-size: 120%;
  }

  .linked.horizontal > button {
    padding: 8px 16px;
    border-top: 1px solid $divider;
    border-radius: 0;
    @extend %button-flat-simple;

    &:first-child { border-bottom-left-radius: $window-radius; }
    &:last-child { border-bottom-right-radius: $window-radius; }
  }
}

// PolKit Dialog
.budgie-polkit-dialog {
  .message { color: $text-secondary; }
  .failure { color: $destructive; }

  > box > grid {
    padding-bottom: 0;
  }
}

// Run Dialog
.budgie-run-dialog {
  entry.search {
    font-size: 120%;
    padding: $space-size 8px + $space-size;
    border-image: none;
    box-shadow: none;
    background-color: transparent;
  }

  list .dim-label { color: $text; }

  scrolledwindow { border-top: 1px solid $divider; }
}

//
// Budgie desktop apps
//

// Budgie setting
.budgie-settings-window {
  > box > scrolledwindow {
    background-color: $base-alt;
    border-bottom-left-radius: $window-radius;

    list.sidebar {
      background-color: transparent;
    }
  }

  buttonbox.inline-toolbar {
    border-style: none none solid;

    button {
      border-radius: $corner-radius;

      @extend %button-flat-simple;
    }
  }
}

button.centerbutton { // FIXME: not work
  &:first-child {
    border-radius: $corner-radius 0 0 $corner-radius;
  }

  &:last-child {
    border-radius: 0 $corner-radius $corner-radius 0;
  }
}
