// Copyright (c) 2016-present Arctic Ice Studio <development@arcticicestudio.com>
// Copyright (c) 2016-present Sven Greb <code@svengreb.de>

// Project:    Nord
// Version:    0.2.0
// Repository: https://github.com/arcticicestudio/nord
// License:    MIT
// References:
// http://sass-lang.com
// http://sassdoc.com


// An arctic, north-bluish color palette.
// Created for the clean- and minimal flat design pattern to achieve a optimal focus and readability for code syntax
// highlighting and UI.
// It consists of a total of sixteen, carefully selected, dimmed pastel colors for a eye-comfortable, but yet colorful
// ambiance.

// @author Arctic Ice Studio <development@arcticicestudio.com>

$nord0: #2e3440;
$nord1: #3b4252;
$nord2: #434c5e;
$nord3: #4c566a;
$nord4: #d8dee9;
$nord5: #e5e9f0;
$nord6: #eceff4;
$nord7: #8fbcbb;
$nord8: #88c0d0;
$nord9: #81a1c1;
$nord10: #5e81ac;
$nord11: #bf616a;
$nord12: #d08770;
$nord13: #ebcb8b;
$nord14: #a3be8c;
$nord15: #b48ead;
