$variant: 'light';
$topbar: 'dark';
$compact: 'false';

@import '../../_sass/variables';
@import '../../_sass/colors';
@import '../../_sass/gtk/colors-libadwaita';
@import '../../_sass/gtk/drawing-4.0';
@import '../../_sass/gtk/common-4.0';
@import '../../_sass/gtk/apps-4.0';
@import '../../_sass/gtk/colors-public';
