/* Private window header bar's URL bar */

@namespace xul url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

:root[privatebrowsingmode="temporary"] #nav-bar toolbarspring:first-of-type:before {
	background: url("../icons/user-not-tracked.svg") no-repeat;
	background-size: contain;
	content: "";
	display: block;
	position: absolute;
	width: 64px;
	height: 64px;
	top: 0;
	opacity: 0.3;
	transform: translate(15px, 0);
}
:root[privatebrowsingmode="temporary"] #nav-bar toolbarspring:first-of-type:-moz-lwtheme-brighttext:before {
	background-image: url("../icons/user-not-tracked-dark.svg");
}

#TabsToolbar .private-browsing-indicator {
	display: none !important;
}
